import argcomplete
import logging
import sys

from .base import BaseClient
from .config import config
from .service import ServiceCmd


class ScalarisCmd(ServiceCmd):

    def __init__(self, parser, client):
        ServiceCmd.__init__(self, parser, client, "scalaris", ['scalaris'],
                            "Scalaris service sub-commands help")


def main():
    logger = logging.getLogger(__name__)
    console = logging.StreamHandler()
    formatter = logging.Formatter('%(levelname)s - %(message)s')
    console.setFormatter(formatter)
    logger.addHandler(console)

    cmd_client = BaseClient(logger)

    parser, argv = config('Manage ConPaaS PHP services.', logger)

    _serv_cmd = ScalarisCmd(parser, cmd_client)

    argcomplete.autocomplete(parser)
    args = parser.parse_args(argv)
    cmd_client.set_config(args.director_url, args.username, args.password,
                          args.debug)
    try:
        args.run_cmd(args)
    except:
        e = sys.exc_info()[1]
        sys.stderr.write("ERROR: %s\n" % e)
        sys.exit(1)

if __name__ == '__main__':
    main()
